pub enum AudioScheduledSourceNodeMessage {
Start(f64),
Stop(f64),
RegisterOnEndedCallback(OnEndedCallback),
}Expand description
Type of message directed to AudioScheduledSourceNodes.
Variants
Start(f64)
Schedules a sound to playback at an exact time.
Stop(f64)
Schedules a sound to stop playback at an exact time.
RegisterOnEndedCallback(OnEndedCallback)
Register onended event callback.